package org.ow2.weblab.portlet.util;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.helper.ResourceHelper;
import org.ow2.weblab.core.model.ComposedQuery;
import org.ow2.weblab.core.model.Query;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.SimilarityQuery;
import org.ow2.weblab.core.model.StringQuery;

public class PortletQueryParser extends WebLabQueryParser {
	private Log logger = LogFactory.getLog(PortletQueryParser.class);

	public String getRequest(Query q, ResourceHelper hlpr) throws WebLabCheckedException {
		if ((q instanceof StringQuery))
			return ((StringQuery) q).getRequest();
		if ((q instanceof ComposedQuery))
			return getComposedRequest((ComposedQuery) q, hlpr);
		if ((q instanceof SimilarityQuery)) {
			SimilarityQuery query = (SimilarityQuery) q;
			StringBuffer queryString = new StringBuffer();
			List<Resource> resources = query.getResource();

			if (resources.size() == 1) {
				queryString.append("id");
				queryString.append(':');
				queryString.append('"');
				queryString.append(((Resource) resources.get(0)).getUri());
				queryString.append('"');
			} else {
				for (int i = 0; i < resources.size(); i++) {
					Resource r = (Resource) resources.get(i);
					if (i > 0) {
						queryString.append(" OR ");
					}
					queryString.append("id");
					queryString.append(':');
					queryString.append('"');
					queryString.append(r.getUri());
					queryString.append('"');
				}
			}
			return queryString.toString();
		}
		throw new WebLabCheckedException("Cannot parse query type : " + q.getClass() + ".");
	}

	public String getComposedRequest(ComposedQuery q, ResourceHelper hlpr) throws WebLabCheckedException {
		String operator = q.getOperator().value();

		StringBuffer queryString = new StringBuffer();
		queryString.append('(');
		for (Query subQ : q.getQuery()) {
			if (queryString.length() > 1) {
				queryString.append(' ');
				queryString.append(operator);
				queryString.append(' ');
			}
			if ((subQ instanceof StringQuery))
				queryString.append(getRequestWithScope((StringQuery) subQ, hlpr));
			else if ((subQ instanceof ComposedQuery))
				queryString.append(getComposedRequest((ComposedQuery) subQ, hlpr));
			else {
				throw new WebLabCheckedException("Solr engine service can only process " + ComposedQuery.class.getSimpleName() + " or "
						+ StringQuery.class.getSimpleName() + ".");
			}
		}

		queryString.append(')');
		return queryString.toString();
	}

	public String getRequestWithScope(Query q, ResourceHelper hlpr) throws WebLabCheckedException {
		List<String> values = hlpr.getRessOnPredSubj(q.getUri(), "http://weblab.ow2.org/core/1.2/ontology/retrieval#hasScope");
		if (values.size() == 0) {
			this.logger.debug("No scope.");
		} else if (values.size() > 1) {
			this.logger
					.info("Query is holding multiple values for [http://weblab.ow2.org/core/1.2/ontology/retrieval#hasScope]. That's not cool, so we ignore all of them.");
		} else {
			String scope = (String) values.get(0);
			if (scope.contains("#"))
				scope = scope.substring(scope.indexOf(35));
			else {
				scope = scope.substring(scope.indexOf(47));
			}
			return scope + ":(" + getRequest(q, hlpr) + ")";
		}
		return getRequest(q, hlpr);
	}

	public String getOrderBy(Query q, ResourceHelper hlpr) throws WebLabCheckedException {
		throw new WebLabCheckedException("Not yet implemented...");
	}

	public boolean getOrder(Query q, ResourceHelper hlpr) throws WebLabCheckedException {
		List<String> values = hlpr.getLitsOnPredSubj(q.getUri(), "http://weblab.ow2.org/core/1.2/ontology/retrieval#ascendentOrderingModeExpected");
		if (values.size() != 1)
			this.logger
					.info("Query is holding multiple values for [http://weblab.ow2.org/core/1.2/ontology/retrieval#ascendentOrderingModeExpected]. That's not well perceived, so we ignore all of them.");
		else {
			return Boolean.parseBoolean((String) values.get(0));
		}
		return false;
	}
}